/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.jackrabbit.oak.segment.spi.persistence.split;

import org.apache.jackrabbit.oak.segment.spi.persistence.JournalFile;
import org.apache.jackrabbit.oak.segment.spi.persistence.JournalFileReader;
import org.apache.jackrabbit.oak.segment.spi.persistence.JournalFileWriter;

import java.io.IOException;
import java.util.Optional;

public class SplitJournalFile implements JournalFile {

    private final JournalFile roJournalFile;

    private final JournalFile rwJournalFile;

    private final Optional<String> lastRoJournalEntry;

    public SplitJournalFile(JournalFile roJournalFile, JournalFile rwJournalFile, Optional<String> lastRoJournalEntry) {
        this.roJournalFile = roJournalFile;
        this.rwJournalFile = rwJournalFile;
        this.lastRoJournalEntry = lastRoJournalEntry;
    }

    @Override
    public JournalFileReader openJournalReader() throws IOException {
        return new SplitJournalFileReader(roJournalFile.openJournalReader(), rwJournalFile.openJournalReader(), lastRoJournalEntry);
    }

    @Override
    public JournalFileWriter openJournalWriter() throws IOException {
        return rwJournalFile.openJournalWriter();
    }

    @Override
    public String getName() {
        return rwJournalFile.getName();
    }

    @Override
    public boolean exists() {
        return roJournalFile.exists() || rwJournalFile.exists();
    }
}
